@@ -197,7 +197,9 @@ def view(ctx, is_raw):
     if not pipeline_name:
         pipeline_name = "(custom)"
     print_tab('pipeline_name', pipeline_name)
-    print_tab('description', workflow_job.description)
+    print_tab('project', workflow_job.project_name)
+    if workflow_job.description:
+        print_tab('description', workflow_job.description)
     submit_date = workflow_job.submit_date
     print_tab('submitted', submit_date.strftime('%Y-%m-%d %H:%M:%S'))
     complete_date = workflow_job.complete_date or datetime.datetime.utcnow()
@@ -211,6 +213,7 @@ def view(ctx, is_raw):
         "%s (%s)"
         % (workflow_job.details.get('pod_name'), workflow_job.details.get('pod_namespace')),
     )
+    print_tab('work dir', workflow_job.work_dir)
     print_tab('script_name', workflow_job.script_name)
     print_tab('revision', (workflow_job.revision or '(latest)'))
     print_tab('user', workflow_job.user_name)
