@@ -12,16 +12,18 @@ from nextcodecli.utils import find_aws_credentials, get_logger
 logging.getLogger('botocore').setLevel(logging.WARNING)
 
 
-def find_job(session, job_id):
+def find_job(service, job_id):
     log = get_logger()
     job_info = None
     job_url = None
+    session = service.session
     if str(job_id) == 'latest':
-        if not session.current_user:
+        print()
+        if not service.current_user:
             log.error("No user in session")
             return None
 
-        user_name = session.current_user['preferred_username']
+        user_name = service.current_user['preferred_username']
         resp = session.get(
             session.url_from_endpoint('jobs'),
             json={
