@@ -9,6 +9,7 @@ import sys
 import json
 from jsonpath_rw import parse
 import yaml
+import dateutil
 
 log_formatter = logging.Formatter('%(asctime)s - %(name)s - %(levelname)s - %(message)s')
 
@@ -147,3 +148,7 @@ def check_profile(ctx):
         abort(
             "You have no active profile or selected profile is invalid. Run 'nextcode profile add [name]'"
         )
+
+
+def fmt_date(dt):
+    return dateutil.parser.parse(dt).strftime("%Y-%m-%d %H:%M")
